@@ -44,7 +44,7 @@
 namespace MagickLib
 {
 #include <magick/MagickCore.h>
-#include <wand/magick-wand.h>
+#include <wand/MagickWand.h>
 #undef inline // Remove possible definition from config.h
 
 #undef class
@@ -104,6 +104,7 @@ namespace Magick
 {
   // The datatype for an RGB component
   using MagickLib::Quantum;
+  using MagickLib::MagickSizeType;
 
   // Boolean types
   using MagickLib::MagickBooleanType;
@@ -128,6 +129,7 @@ namespace Magick
   using MagickLib::OpacityChannel;
   using MagickLib::BlackChannel;
   using MagickLib::MatteChannel;
+  using MagickLib::DefaultChannels;
   
   // Color-space types
   using MagickLib::CMYKColorspace;
@@ -136,6 +138,7 @@ namespace Magick
   using MagickLib::HSLColorspace;
   using MagickLib::HWBColorspace;
   using MagickLib::LABColorspace;
+  using MagickLib::LogColorspace;
   using MagickLib::OHTAColorspace;
   using MagickLib::Rec601LumaColorspace;
   using MagickLib::Rec709LumaColorspace;
@@ -153,19 +156,26 @@ namespace Magick
   // Composition operations
   using MagickLib::AddCompositeOp;
   using MagickLib::AtopCompositeOp;
+  using MagickLib::BlendCompositeOp;
   using MagickLib::BumpmapCompositeOp;
   using MagickLib::ClearCompositeOp;
   using MagickLib::ColorizeCompositeOp;
   using MagickLib::CompositeOperator;
   using MagickLib::CopyBlueCompositeOp;
   using MagickLib::CopyCompositeOp;
+  using MagickLib::CopyCyanCompositeOp;
   using MagickLib::CopyGreenCompositeOp;
+  using MagickLib::CopyMagentaCompositeOp;
   using MagickLib::CopyOpacityCompositeOp;
   using MagickLib::CopyRedCompositeOp;
+  using MagickLib::CopyYellowCompositeOp;
   using MagickLib::DarkenCompositeOp;
   using MagickLib::DifferenceCompositeOp;
   using MagickLib::DisplaceCompositeOp;
   using MagickLib::DissolveCompositeOp;
+  using MagickLib::DstOverCompositeOp;
+  using MagickLib::ExclusionCompositeOp;
+  using MagickLib::HardLightCompositeOp;
   using MagickLib::HueCompositeOp;
   using MagickLib::InCompositeOp;
   using MagickLib::LightenCompositeOp;
@@ -180,13 +190,11 @@ namespace Magick
   using MagickLib::PlusCompositeOp;
   using MagickLib::SaturateCompositeOp;
   using MagickLib::ScreenCompositeOp;
+  using MagickLib::SoftLightCompositeOp;
   using MagickLib::SubtractCompositeOp;
   using MagickLib::ThresholdCompositeOp;
   using MagickLib::UndefinedCompositeOp;
   using MagickLib::XorCompositeOp;
-  using MagickLib::CopyCyanCompositeOp;
-  using MagickLib::CopyMagentaCompositeOp;
-  using MagickLib::CopyYellowCompositeOp;
   using MagickLib::CopyBlackCompositeOp;
   
   // Compression algorithms
@@ -628,13 +636,13 @@ namespace Magick
   using MagickLib::GetDrawInfo;
   using MagickLib::GetExceptionInfo;
   using MagickLib::GetGeometry;
-  using MagickLib::GetImageAttribute;
   using MagickLib::GetImageBoundingBox;
   using MagickLib::GetImageChannelDepth;
   using MagickLib::GetImageDepth;
   using MagickLib::GetImageInfo;
   using MagickLib::GetImageOption;
   using MagickLib::GetImagePixels;
+  using MagickLib::GetImageProperty;
   using MagickLib::GetImageProfile;
   using MagickLib::GetImageQuantizeError;
   using MagickLib::GetImageType;
@@ -646,13 +654,13 @@ namespace Magick
   using MagickLib::GetPageGeometry;
   using MagickLib::GetPixels;
   using MagickLib::GetQuantizeInfo;
+  using MagickLib::GetQuantumInfo;
   using MagickLib::GetTypeMetrics;
   using MagickLib::GlobExpression;
   using MagickLib::GreaterValue;
   using MagickLib::HSLTransform;
   using MagickLib::HeightValue;
   using MagickLib::IdentityAffine;
-  using MagickLib::ImageAttribute;
   using MagickLib::ImageError;
   using MagickLib::ImageFatalError;
   using MagickLib::ImageInfo;
@@ -713,6 +721,7 @@ namespace Magick
   using MagickLib::ProfileInfo;
   using MagickLib::QuantizeImage;
   using MagickLib::QuantizeInfo;
+  using MagickLib::QuantumInfo;
   using MagickLib::QueryColorDatabase;
   using MagickLib::RGBTransformImage;
   using MagickLib::RaiseImage;
@@ -727,6 +736,7 @@ namespace Magick
   using MagickLib::RegistryWarning;
   using MagickLib::RelinquishMagickMemory;
   using MagickLib::RemoveImageOption;
+  using MagickLib::ResizeImage;
   using MagickLib::ResizeMagickMemory;
   using MagickLib::ResourceLimitError;
   using MagickLib::ResourceLimitFatalError;
@@ -740,7 +750,6 @@ namespace Magick
   using MagickLib::SetCacheView;
   using MagickLib::SetClientName;
   using MagickLib::SetImage;
-  using MagickLib::SetImageAttribute;
   using MagickLib::SetImageChannelDepth;
   using MagickLib::SetImageClipMask;
   using MagickLib::SetImageDepth;
@@ -749,6 +758,7 @@ namespace Magick
   using MagickLib::SetImageOption;
   using MagickLib::SetImagePixels;
   using MagickLib::SetImageProfile;
+  using MagickLib::SetImageProperty;
   using MagickLib::SetImageType;
   using MagickLib::SetLogEventMask;
   using MagickLib::SetMagickInfo;
@@ -758,6 +768,7 @@ namespace Magick
   using MagickLib::SharpenImage;
   using MagickLib::ShaveImage;
   using MagickLib::ShearImage;
+  using MagickLib::SigmoidalContrastImageChannel;
   using MagickLib::SignatureImage;
   using MagickLib::SizeBlob;
   using MagickLib::SolarizeImage;
@@ -779,6 +790,7 @@ namespace Magick
   using MagickLib::TransformImage;
   using MagickLib::TransformRGBImage;
   using MagickLib::TransparentImage;
+  using MagickLib::TrimImage;
   using MagickLib::TypeError;
   using MagickLib::TypeFatalError;
   using MagickLib::TypeWarning;
