@@ -27,9 +27,9 @@ extern WandExport ChannelStatistics
   *MagickGetImageChannelStatistics(MagickWand *);
 
 extern WandExport char
-  *MagickGetImageAttribute(MagickWand *,const char *),
   *MagickGetImageFilename(MagickWand *),
   *MagickGetImageFormat(MagickWand *),
+  *MagickGetImageProperty(MagickWand *,const char *),
   *MagickGetImageSignature(MagickWand *),
   *MagickIdentifyImage(MagickWand *);
 
@@ -50,6 +50,7 @@ extern WandExport double
   MagickGetImageTotalInkDensity(MagickWand *);
 
 extern WandExport Image
+  *MagickDestroyImage(Image *),
   *GetImageFromMagickWand(MagickWand *);
 
 extern WandExport ImageType
@@ -58,7 +59,18 @@ extern WandExport ImageType
 extern WandExport InterlaceType
   MagickGetImageInterlaceScheme(MagickWand *);
 
+extern WandExport InterpolatePixelMethod
+  MagickGetImageInterpolateMethod(MagickWand *);
+
 extern WandExport MagickBooleanType
+  MagickAdaptiveBlurImage(MagickWand *,const double,const double),
+  MagickAdaptiveBlurImageChannel(MagickWand *,const ChannelType,const double,
+    const double),
+  MagickAdaptiveResizeImage(MagickWand *,const unsigned long,
+    const unsigned long),
+  MagickAdaptiveSharpenImage(MagickWand *,const double,const double),
+  MagickAdaptiveSharpenImageChannel(MagickWand *,const ChannelType,const double,
+    const double),
   MagickAdaptiveThresholdImage(MagickWand *,const unsigned long,
     const unsigned long,const long),
   MagickAddImage(MagickWand *,const MagickWand *),
@@ -109,6 +121,8 @@ extern WandExport MagickBooleanType
   MagickEvaluateImage(MagickWand *,const MagickEvaluateOperator,const double),
   MagickEvaluateImageChannel(MagickWand *,const ChannelType,
     const MagickEvaluateOperator,const double),
+  MagickExtentImage(MagickWand *,const unsigned long,const unsigned long,
+    const long,const long),
   MagickFlipImage(MagickWand *),
   MagickFlopImage(MagickWand *),
   MagickFrameImage(MagickWand *,const PixelWand *,const unsigned long,
@@ -133,6 +147,7 @@ extern WandExport MagickBooleanType
   MagickGetImageGreenPrimary(MagickWand *,double *,double *),
   MagickGetImageMatte(MagickWand *),
   MagickGetImageMatteColor(MagickWand *,PixelWand *),
+  MagickGetImageLength(MagickWand *,MagickSizeType *),
   MagickGetImagePage(MagickWand *,unsigned long *,unsigned long *,long *,
     long *),
   MagickGetImagePixelColor(MagickWand *,const long,const long,PixelWand *),
@@ -148,9 +163,10 @@ extern WandExport MagickBooleanType
   MagickLevelImage(MagickWand *,const double,const double,const double),
   MagickLevelImageChannel(MagickWand *,const ChannelType,const double,
     const double,const double),
+  MagickLinearStretchImage(MagickWand *,const double,const double),
   MagickMagnifyImage(MagickWand *),
   MagickMapImage(MagickWand *,const MagickWand *,const MagickBooleanType),
-  MagickMatteFloodfillImage(MagickWand *,const Quantum,const double,
+  MagickMatteFloodfillImage(MagickWand *,const double,const double,
     const PixelWand *,const long,const long),
   MagickMedianFilterImage(MagickWand *,const double),
   MagickMinifyImage(MagickWand *),
@@ -165,18 +181,23 @@ extern WandExport MagickBooleanType
   MagickNormalizeImage(MagickWand *),
   MagickNormalizeImageChannel(MagickWand *,const ChannelType),
   MagickOilPaintImage(MagickWand *,const double),
+  MagickOrderedPosterizeImage(MagickWand *,const char *),
+  MagickOrderedPosterizeImageChannel(MagickWand *,const ChannelType,
+    const char *),
   MagickPaintOpaqueImage(MagickWand *,const PixelWand *,const PixelWand *,
     const double),
-  MagickPaintTransparentImage(MagickWand *,const PixelWand *,const Quantum,
+  MagickPaintOpaqueImageChannel(MagickWand *,const ChannelType,
+    const PixelWand *,const PixelWand *,const double),
+  MagickPaintTransparentImage(MagickWand *,const PixelWand *,const double,
     const double),
   MagickPingImage(MagickWand *,const char *),
-  MagickPingImageBlob(MagickWand *,const void *,const size_t length),
+  MagickPingImageBlob(MagickWand *,const void *,const size_t),
   MagickPingImageFile(MagickWand *,FILE *),
+  MagickPolaroidImage(MagickWand *,const DrawingWand *,const double),
   MagickPosterizeImage(MagickWand *,const unsigned long,
     const MagickBooleanType),
   MagickPreviousImage(MagickWand *),
-  MagickProfileImage(MagickWand *,const char *,const void *,
-    const unsigned long),
+  MagickProfileImage(MagickWand *,const char *,const void *,const size_t),
   MagickQuantizeImage(MagickWand *,const unsigned long,const ColorspaceType,
     const unsigned long,const MagickBooleanType,const MagickBooleanType),
   MagickQuantizeImages(MagickWand *,const unsigned long,const ColorspaceType,
@@ -189,8 +210,9 @@ extern WandExport MagickBooleanType
   MagickRandomThresholdImageChannel(MagickWand *,const ChannelType,const double,
     const double),
   MagickReadImage(MagickWand *,const char *),
-  MagickReadImageBlob(MagickWand *,const void *,const size_t length),
+  MagickReadImageBlob(MagickWand *,const void *,const size_t),
   MagickReadImageFile(MagickWand *,FILE *),
+  MagickRecolorImage(MagickWand *,const unsigned long,const double *),
   MagickReduceNoiseImage(MagickWand *,const double),
   MagickRemoveImage(MagickWand *),
   MagickResampleImage(MagickWand *,const double,const double,const FilterTypes,
@@ -201,16 +223,18 @@ extern WandExport MagickBooleanType
   MagickRotateImage(MagickWand *,const PixelWand *,const double),
   MagickSampleImage(MagickWand *,const unsigned long,const unsigned long),
   MagickScaleImage(MagickWand *,const unsigned long,const unsigned long),
+  MagickSegmentImage(MagickWand *,const ColorspaceType,const MagickBooleanType,
+    const double,const double),
   MagickSeparateImageChannel(MagickWand *,const ChannelType),
   MagickSepiaToneImage(MagickWand *,const double),
   MagickSetImage(MagickWand *,const MagickWand *),
-  MagickSetImageAttribute(MagickWand *,const char *,const char *),
   MagickSetImageBackgroundColor(MagickWand *,const PixelWand *),
   MagickSetImageBias(MagickWand *,const double),
   MagickSetImageBluePrimary(MagickWand *,const double,const double),
   MagickSetImageBorderColor(MagickWand *,const PixelWand *),
   MagickSetImageChannelDepth(MagickWand *,const ChannelType,
     const unsigned long),
+  MagickSetImageClipMask(MagickWand *,const MagickWand *),
   MagickSetImageColormapColor(MagickWand *,const unsigned long,
     const PixelWand *),
   MagickSetImageCompose(MagickWand *,const CompositeOperator),
@@ -226,15 +250,18 @@ extern WandExport MagickBooleanType
   MagickSetImageFilename(MagickWand *,const char *),
   MagickSetImageFormat(MagickWand *,const char *),
   MagickSetImageInterlaceScheme(MagickWand *,const InterlaceType),
+  MagickSetImageInterpolateMethod(MagickWand *,
+    const InterpolatePixelMethod),
   MagickSetImageIterations(MagickWand *,const unsigned long),
   MagickSetImageMatte(MagickWand *,const MagickBooleanType),
   MagickSetImageMatteColor(MagickWand *,const PixelWand *),
+  MagickSetImageOpacity(MagickWand *,const double),
   MagickSetImagePage(MagickWand *,const unsigned long,const unsigned long,
     const long,const long),
   MagickSetImagePixels(MagickWand *,const long,const long,const unsigned long,
     const unsigned long,const char *,const StorageType,const void *),
-  MagickSetImageProfile(MagickWand *,const char *,const void *,
-    const unsigned long),
+  MagickSetImageProfile(MagickWand *,const char *,const void *,const size_t),
+  MagickSetImageProperty(MagickWand *,const char *,const char *),
   MagickSetImageRedPrimary(MagickWand *,const double,const double),
   MagickSetImageRenderingIntent(MagickWand *,const RenderingIntent),
   MagickSetImageResolution(MagickWand *,const double,const double),
@@ -242,7 +269,6 @@ extern WandExport MagickBooleanType
   MagickSetImageTicksPerSecond(MagickWand *,const unsigned long),
   MagickSetImageType(MagickWand *,const ImageType),
   MagickSetImageUnits(MagickWand *,const ResolutionType),
-  MagickSetImageVirtualPixelMethod(MagickWand *,const VirtualPixelMethod),
   MagickSetImageWhitePoint(MagickWand *,const double,const double),
   MagickShadeImage(MagickWand *,const MagickBooleanType,const double,const 
     double),
@@ -257,6 +283,7 @@ extern WandExport MagickBooleanType
     const double,const double),
   MagickSigmoidalContrastImageChannel(MagickWand *,const ChannelType,
     const MagickBooleanType,const double,const double),
+  MagickSketchImage(MagickWand *,const double,const double,const double),
   MagickSolarizeImage(MagickWand *,const double),
   MagickSpliceImage(MagickWand *,const unsigned long,const unsigned long,
     const long,const long),
@@ -264,10 +291,13 @@ extern WandExport MagickBooleanType
   MagickStripImage(MagickWand *),
   MagickSwirlImage(MagickWand *,const double),
   MagickTintImage(MagickWand *,const PixelWand *,const PixelWand *),
+  MagickTransposeImage(MagickWand *),
+  MagickTransverseImage(MagickWand *),
   MagickThresholdImage(MagickWand *,const double),
   MagickThresholdImageChannel(MagickWand *,const ChannelType,const double),
   MagickThumbnailImage(MagickWand *,const unsigned long,const unsigned long),
   MagickTrimImage(MagickWand *,const double),
+  MagickUniqueImageColors(MagickWand *),
   MagickUnsharpMaskImage(MagickWand *,const double,const double,const double,
     const double),
   MagickUnsharpMaskImageChannel(MagickWand *,const ChannelType,const double,
@@ -285,9 +315,6 @@ WandExport MagickProgressMonitor
   MagickSetImageProgressMonitor(MagickWand *,const MagickProgressMonitor,
     void *);
 
-extern WandExport MagickSizeType
-  MagickGetImageSize(MagickWand *);
-
 extern WandExport MagickWand
   *MagickAppendImages(MagickWand *,const MagickBooleanType),
   *MagickAverageImages(MagickWand *),
@@ -297,17 +324,20 @@ extern WandExport MagickWand
     const MetricType,double *),
   *MagickCompareImages(MagickWand *,const MagickWand *,const MetricType,
     double *),
+  *MagickCompareImageLayers(MagickWand *,const MagickLayerMethod),
   *MagickDeconstructImages(MagickWand *),
   *MagickFlattenImages(MagickWand *),
   *MagickFxImage(MagickWand *,const char *),
   *MagickFxImageChannel(MagickWand *,const ChannelType,const char *),
   *MagickGetImage(MagickWand *),
+  *MagickGetImageClipMask(MagickWand *),
   *MagickGetImageRegion(MagickWand *,const unsigned long,const unsigned long,
     const long,const long),
   *MagickMorphImages(MagickWand *,const unsigned long),
   *MagickMosaicImages(MagickWand *),
   *MagickMontageImage(MagickWand *,const DrawingWand *,const char *,
     const char *,const MontageMode,const char *),
+  *MagickOptimizeImageLayers(MagickWand *),
   *MagickPreviewImages(MagickWand *wand,const PreviewType),
   *MagickSteganoImage(MagickWand *,const MagickWand *,const long),
   *MagickStereoImage(MagickWand *,const MagickWand *),
@@ -327,8 +357,8 @@ extern WandExport ResolutionType
 extern WandExport unsigned char
   *MagickGetImageBlob(MagickWand *,size_t *),
   *MagickGetImagesBlob(MagickWand *,size_t *),
-  *MagickGetImageProfile(MagickWand *,const char *,unsigned long *),
-  *MagickRemoveImageProfile(MagickWand *,const char *,unsigned long *);
+  *MagickGetImageProfile(MagickWand *,const char *,size_t *),
+  *MagickRemoveImageProfile(MagickWand *,const char *,size_t *);
 
 extern WandExport unsigned long
   MagickGetImageColors(MagickWand *),
@@ -350,7 +380,8 @@ extern WandExport VirtualPixelMethod
   Deprecated methods.
 */
 extern WandExport char
-  *MagickDescribeImage(MagickWand *);
+  *MagickDescribeImage(MagickWand *),
+  *MagickGetImageAttribute(MagickWand *,const char *);
 
 extern WandExport long
   MagickGetImageIndex(MagickWand *);
@@ -358,18 +389,25 @@ extern WandExport long
 extern WandExport MagickBooleanType
   MagickOpaqueImage(MagickWand *,const PixelWand *,const PixelWand *,
     const double),
+  MagickSetImageAttribute(MagickWand *,const char *,const char *),
   MagickSetImageIndex(MagickWand *,const long),
   MagickSetImageOption(MagickWand *,const char *,const char *,const char *),
-  MagickTransparentImage(MagickWand *,const PixelWand *,const Quantum,
+  MagickTransparentImage(MagickWand *,const PixelWand *,const double,
     const double);
 
 extern WandExport MagickWand
   *MagickRegionOfInterestImage(MagickWand *,const unsigned long,
-	  const unsigned long,const long,const long);
+    const unsigned long,const long,const long);
+
+extern WandExport MagickSizeType
+  MagickGetImageSize(MagickWand *);
 
 extern WandExport unsigned char
   *MagickWriteImageBlob(MagickWand *,size_t *);
 
+extern WandExport VirtualPixelMethod
+  MagickSetImageVirtualPixelMethod(MagickWand *,const VirtualPixelMethod);
+
 #if defined(__cplusplus) || defined(c_plusplus)
 }
 #endif
